import { PlatformAccessory, CharacteristicValue } from 'homebridge';
import { BoMForecastPlatform } from './platform';
/**
 * Platform Accessory
 * An instance of this class is created for each accessory your platform registers
 * Each accessory may expose multiple services of different service types.
 */
export declare class BoMForecastAccessory {
    private readonly platform;
    private readonly accessory;
    private service;
    constructor(platform: BoMForecastPlatform, accessory: PlatformAccessory);
    /**
     * Handle the "GET" requests from HomeKit
     * These are sent when HomeKit wants to know the current state of the accessory, for example, checking if a Light bulb is on.
     *
     * GET requests should return as fast as possbile. A long delay here will result in
     * HomeKit being unresponsive and a bad user experience in general.
     *
     * If your device takes time to respond you should update the status of your device
     * asynchronously instead using the `updateCharacteristic` method instead.
     *
     * this.service.updateCharacteristic(this.platform.Characteristic.On, true)
     */
    getTemp(): Promise<CharacteristicValue>;
    /**
     * Updating characteristics values asynchronously using the `updateCharacteristic` method.
     */
    scheduleUpdates(remoteFile: any, delayMinutes: any, temperatureSensorMaxService: any): Promise<void>;
    /**
     * Download the BoM Forecast file
     */
    downloadFromBoM(dstFile: any, srcFile: any): Promise<void>;
    /**
     * Parse the BoM Forecast file
     */
    bomXmlToJson(srcFile: any): Promise<any>;
    /**
     * Extract the first air_temperature_maximum from the forecast
     */
    extractMaxTemp(jsonObj: any): Promise<string>;
}
//# sourceMappingURL=platformAccessory.d.ts.map